# Generated by Django 4.2.23 on 2025-06-11 09:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("djinsight", "0001_initial"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="pageviewlog",
            new_name="djinsight_p_page_id_f86134_idx",
            old_name="djinsight_p_page_id_a3ba77_idx",
        ),
        migrations.RenameIndex(
            model_name="pageviewlog",
            new_name="djinsight_p_content_4f4405_idx",
            old_name="djinsight_p_content_7eddbf_idx",
        ),
        migrations.RenameIndex(
            model_name="pageviewlog",
            new_name="djinsight_p_session_54f5b5_idx",
            old_name="djinsight_p_session_b10779_idx",
        ),
        migrations.RenameIndex(
            model_name="pageviewlog",
            new_name="djinsight_p_timesta_9736c6_idx",
            old_name="djinsight_p_timesta_9d0cb4_idx",
        ),
        migrations.RenameIndex(
            model_name="pageviewsummary",
            new_name="djinsight_p_page_id_efa5ff_idx",
            old_name="djinsight_p_page_id_cd69db_idx",
        ),
        migrations.RenameIndex(
            model_name="pageviewsummary",
            new_name="djinsight_p_content_912dc8_idx",
            old_name="djinsight_p_content_07ac79_idx",
        ),
        migrations.RenameIndex(
            model_name="pageviewsummary",
            new_name="djinsight_p_date_4cf884_idx",
            old_name="djinsight_p_date_fbf615_idx",
        ),
    ]
